@@ -1,7 +1,6 @@
 from ..utils.utils import resource_path
 import os
 import json
-import zipfile
 import shutil
 import time
 import win32com.shell.shell as shell
@@ -20,24 +19,26 @@ def product_visualization_export(
         vstitcher_launcher_file: str,
         work_path: str,
         project_file_name: str,
-        body_sizes: dict
+        body_sizes: dict,
+        person_sex: str
 ) -> str:
 
     # copy plugin script to VStitcher folder
     plugin_path = os.path.join(vstitcher_data_path, 'Plugins')
     plugin_folder = os.path.join(plugin_path, PLUGIN_PATH_NAME)
-    with zipfile.ZipFile(resource_path('\\vstitcher_plugins\\product_visualization_export.zip'), 'r') as zip_ref:
 
-        # clean previous version of plugin
-        if os.path.exists(plugin_folder) and os.path.isdir(plugin_folder):
-            shutil.rmtree(plugin_folder)
+    # clean previous version of plugin
+    if os.path.exists(plugin_folder) and os.path.isdir(plugin_folder):
+        shutil.rmtree(plugin_folder)
 
-        zip_ref.extractall(plugin_folder)
+    # copy files
+    shutil.copytree(resource_path('vstitcher_plugins/product_visualization_export'), plugin_folder)
 
     # set up task params
     params = {
         'body_sizes': body_sizes,
         'work_path': work_path,
+        'person_sex': person_sex,
     }
 
     # save JSON params to file
@@ -71,6 +72,21 @@ def product_visualization_export(
     time.sleep(0.1)
     pyautogui.hotkey('enter')
 
+    # select size
+    time.sleep(0.1)
+    pyautogui.hotkey('tab')
+    time.sleep(0.1)
+    pyautogui.hotkey('tab')
+    time.sleep(0.1)
+    pyautogui.hotkey('down')
+    time.sleep(0.1)
+    pyautogui.hotkey('tab')
+    time.sleep(0.1)
+    pyautogui.hotkey('enter')
+
+    # todo callback?
+    time.sleep(6)
+
     # import with custom callback
     pyautogui.hotkey('ctrl', 'shift', 'i')
     pyautogui.hotkey('delete')
